Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Image ¶
type Image struct {
// The container repository
Repository string `json:"repository,omitempty"`
// The container tag
Tag string `json:"tag,omitempty"`
PullPolicy v1.PullPolicy `json:"pullPolicy,omitempty"`
}
Image represents the container image of a pod
func (Image) Name ¶
Name returns the actual docker image name in the format <repository>:<tag> Deprecated. New code should use ToString
func (*Image) SetDefaults ¶
func (in *Image) SetDefaults(repository, tag string, pullPolicy v1.PullPolicy) (changed bool)
type PodConfig ¶
type PodConfig struct {
// Affinity defines the pod's scheduling constraints
Affinity v1.Affinity `json:"affinity,omitempty"`
NodeSelector map[string]string `json:"nodeSelector,omitempty"`
// Optional duration in seconds the pod may be active on the node relative to
// StartTime before the system will actively try to mark it failed and kill associated containers.
// Value must be a positive integer.
ActiveDeadlineSeconds int64 `json:"activeDeadlineSeconds,omitempty"`
// Restart policy for all containers within the pod.
// One of Always, OnFailure, Never.
// Default to Always.
RestartPolicy v1.RestartPolicy `json:"restartPolicy,omitempty"`
// PodSecurityContext holds pod-level security attributes and common container settings.
// Some fields are also present in container.securityContext. Field values of
// container.securityContext take precedence over field values of PodSecurityContext.
SecurityContext v1.PodSecurityContext `json:"securityContext,omitempty"`
// Tolerations are attached to tolerates any taint that matches
// the triple <key,value,effect> using the matching operator <operator>.
Tolerations []v1.Toleration `json:"tolerations,omitempty"`
// Labels defines the labels to attach to the broker pod
Labels map[string]string `json:"labels,omitempty"`
// Annotations defines the annotations to attach to the pod
Annotations map[string]string `json:"annotations,omitempty"`
// TerminationGracePeriodSeconds is the duration in seconds after the processes running in the pod are sent
// a termination signal and the time when the processes are forcibly halted with a kill signal.
// Set this value longer than the expected cleanup time for your process.
// Defaults to 30 seconds.
// +optional
TerminationGracePeriodSeconds *int64 `json:"terminationGracePeriodSeconds,omitempty"`
}
PodConfig defines the configurations of a kubernetes pod
func (*PodConfig) DeepCopy ¶ added in v0.1.8
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PodConfig.
func (*PodConfig) DeepCopyInto ¶ added in v0.1.8
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
Click to show internal directories.
Click to hide internal directories.